builder

Values

pub fn execute_builders(builders: List(core.Builder)) -> Nil

Execute the provided list of builders

When run with the “watch” argument, starts a file watcher that continuously monitors the source directory and rebuilds on changes. Otherwise, performs a single build pass.

pub fn new_generic_builder(
  source_extensions: List(String),
  build: fn(context.BuildContext, asset.BuildAsset) -> Nil,
) -> core.Builder

Execute a build function on each files matching the source extensions

pub fn new_generic_multiple_builder(
  source_extensions: List(String),
  build: fn(context.BuildContext, List(asset.BuildAsset)) -> Nil,
) -> core.Builder

Execute a unique build function on multiple files in one step

pub fn new_gleam_builder(
  build: fn(context.BuildContext, asset.GleamAsset) -> Nil,
) -> core.Builder

Execute a build function on every gleam files

pub fn new_gleam_multiple_builder(
  build: fn(context.BuildContext, List(asset.GleamAsset)) -> Nil,
) -> core.Builder

Execute a unique build function on multiple files

Search Document