builder/format
Values
pub fn format_gleam_code(code: String) -> Result(String, Nil)
Format Gleam source code using the standard gleam formatter
Runs the code through gleam format --stdin and returns the formatted result.
pub fn format_gleam_code(code: String) -> Result(String, Nil)
Format Gleam source code using the standard gleam formatter
Runs the code through gleam format --stdin and returns the formatted result.